@@ -157,7 +157,7 @@ class Update:
             user = self.slack_emails[email]
             user_id = user["id"]
             # skip deleted and single-channel guest users
-            if not user["deleted"] and not user["is_ultra_restricted"] and user_id not in users:
+            if not user["deleted"] and not user["is_restricted"] and not user["is_ultra_restricted"] and user_id not in users:
                 users.append(user_id)
         return users
 
